aboutsummaryrefslogtreecommitdiff
path: root/Minecraft.Client/Orbis/user_new.cpp
diff options
context:
space:
mode:
authorModMaker101 <119018978+ModMaker101@users.noreply.github.com>2026-03-07 21:56:03 -0500
committerGitHub <noreply@github.com>2026-03-08 09:56:03 +0700
commita9be52c41a02d207233199e98898fe7483d7e817 (patch)
tree71dfaec3a86b05e9ca409b97d8eb9d7f993bfdd0 /Minecraft.Client/Orbis/user_new.cpp
parent1be5faaea781402e7de06b263eeca4c688b7712c (diff)
Project modernization (#630)
* Fixed boats falling and a TP glitch #266 * Replaced every C-style cast with C++ ones * Replaced every C-style cast with C++ ones * Fixed boats falling and a TP glitch #266 * Updated NULL to nullptr and fixing some type issues * Modernized and fixed a few bugs - Replaced most instances of `NULL` with `nullptr`. - Replaced most `shared_ptr(new ...)` with `make_shared`. - Removed the `nullptr` macro as it was interfering with the actual nullptr keyword in some instances. * Fixing more conflicts * Replace int loops with size_t and start work on overrides
Diffstat (limited to 'Minecraft.Client/Orbis/user_new.cpp')
-rw-r--r--Minecraft.Client/Orbis/user_new.cpp28
1 files changed, 14 insertions, 14 deletions
diff --git a/Minecraft.Client/Orbis/user_new.cpp b/Minecraft.Client/Orbis/user_new.cpp
index 83aa3f8c..e3108354 100644
--- a/Minecraft.Client/Orbis/user_new.cpp
+++ b/Minecraft.Client/Orbis/user_new.cpp
@@ -26,13 +26,13 @@ void *user_new(std::size_t size) throw(std::bad_alloc)
if (size == 0)
size = 1;
- while ((ptr = (void *)std::malloc(size)) == NULL) {
+ while ((ptr = (void *)std::malloc(size)) == nullptr) {
//E Obtain new_handler
//J new_handler を取得する
std::new_handler handler = std::get_new_handler();
//E When new_handler is a NULL pointer, bad_alloc is send. If not, new_handler is called.
//J new_handler が NULL ポインタの場合、bad_alloc を送出する、そうでない場合、new_handler を呼び出す
if (!handler)
{
assert(0);//throw std::bad_alloc();
@@ -54,27 +54,27 @@ void *user_new(std::size_t size, const std::nothrow_t& x) throw()
// if (size == 0)
// size = 1;
//
-// while ((ptr = (void *)std::malloc(size)) == NULL) {
+// while ((ptr = (void *)std::malloc(size)) == nullptr) {
// //E Obtain new_handler
// //J new_handler を取得する
// std::new_handler handler = std::get_new_handler();
//
// //E When new_handler is a NULL pointer, NULL is returned.
// //J new_handler が NULL ポインタの場合、NULL を返す
// if (!handler)
-// return NULL;
+// return nullptr;
//
// //E Call new_handler. If new_handler sends bad_alloc, NULL is returned.
// //J new_handler を呼び出す、new_handler が bad_alloc を送出した場合、NULL を返す
// try {
// (*handler)();
// } catch (std::bad_alloc) {
-// return NULL;
+// return nullptr;
// }
// }
// return ptr;
assert(0);
- return NULL;
+ return nullptr;
}
//E Replace operator new[].
@@ -95,9 +95,9 @@ void *user_new_array(std::size_t size, const std::nothrow_t& x) throw()
//J operator delete と置き換わる
void user_delete(void *ptr) throw()
{
- //E In the case of the NULL pointer, no action will be taken.
- //J NULL ポインタの場合、何も行わない
- if (ptr != NULL)
+ //E In the case of the nullptr pointer, no action will be taken.
+ //J nullptr ポインタの場合、何も行わない
+ if (ptr != nullptr)
std::free(ptr);
}
@@ -26,13 +26,13 @@ void *user_new(std::size_t size) throw(std::bad_alloc)
//J new_handler を取得する
std::new_handler handler = std::get_new_handler();
- //E When new_handler is a NULL pointer, bad_alloc is send. If not, new_handler is called.
- //J new_handler が NULL ポインタの場合、bad_alloc を送出する、そうでない場合、new_handler を呼び出す
+ //E When new_handler is a nullptr pointer, bad_alloc is send. If not, new_handler is called.
+ //J new_handler が nullptr ポインタの場合、bad_alloc を送出する、そうでない場合、new_handler を呼び出す
if (!handler)
{
@@ -54,27 +54,27 @@ void *user_new(std::size_t size, const std::nothrow_t& x) throw()
// std::new_handler handler = std::get_new_handler();
//
-// //E When new_handler is a NULL pointer, NULL is returned.
-// //J new_handler が NULL ポインタの場合、NULL を返す
+// //E When new_handler is a nullptr pointer, nullptr is returned.
+// //J new_handler が nullptr ポインタの場合、nullptr を返す
// if (!handler)
@@ -54,27 +54,27 @@ void *user_new(std::size_t size, const std::nothrow_t& x) throw()
//
-// //E Call new_handler. If new_handler sends bad_alloc, NULL is returned.
-// //J new_handler を呼び出す、new_handler が bad_alloc を送出した場合、NULL を返す
+// //E Call new_handler. If new_handler sends bad_alloc, nullptr is returned.
+// //J new_handler を呼び出す、new_handler が bad_alloc を送出した場合、nullptr を返す
// try {
// (*handler)();